.. Copyright (C) 2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2016 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`NetBox <https://github.com/digitalocean/netbox/>`_ is an IP address management
(`IPAM <https://en.wikipedia.org/wiki/IP_address_management>`_) and data center
infrastructure management (`DCIM <https://en.wikipedia.org/wiki/Data_center_infrastructure_management>`_)
application developed by `DigitalOcean <https://digitalocean.com/>`_.
